@@ -1,3 +1,3 @@
 #!/usr/bin/env python
 #-*- coding: utf-8 -*-
-name = "cqTools"
\ No newline at end of file
+__all__ = ['StudentSearch']
